import { AfterContentInit, AfterViewInit, ChangeDetectorRef, EventEmitter, ComponentFactoryResolver, ElementRef, IterableDiffers, NgZone, OnInit, QueryList, TemplateRef, ViewContainerRef, Injector, NgModuleRef, ApplicationRef } from '@angular/core';
import { IgxGridBaseDirective } from '../grid-base.directive';
import { IgxFilteringService } from '../filtering/grid-filtering.service';
import { IgxGridSelectionService } from '../selection/selection.service';
import { GridType, RowType } from '../common/grid.interface';
import { IgxGridSummaryService } from '../summaries/grid-summary.service';
import { IDimensionsChange, IPivotConfiguration, IPivotDimension, IValuesChange } from './pivot-grid.interface';
import { IgxPivotHeaderRowComponent } from './pivot-header-row.component';
import { IgxColumnComponent } from '../columns/column.component';
import { GridPagingMode, GridSummaryCalculationMode, GridSummaryPosition } from '../common/enums';
import { OverlaySettings } from '../../services/public_api';
import { IColumnMovingEndEventArgs, IColumnMovingEventArgs, IColumnMovingStartEventArgs, IColumnVisibilityChangedEventArgs, IGridEditDoneEventArgs, IGridEditEventArgs, IPinColumnCancellableEventArgs, IPinColumnEventArgs, IPinRowEventArgs, IRowDataEventArgs, IRowDragEndEventArgs, IRowDragStartEventArgs } from '../common/events';
import { IgxGridRowComponent } from '../grid/grid-row.component';
import { DropPosition } from '../moving/moving.service';
import { IgxGridExcelStyleFilteringComponent } from '../filtering/excel-style/grid.excel-style-filtering.component';
import { IgxPivotGridNavigationService } from './pivot-grid-navigation.service';
import { IgxColumnResizingService } from '../resizing/resizing.service';
import { IgxFlatTransactionFactory, IgxOverlayService, State, Transaction, TransactionService } from '../../services/public_api';
import { IDisplayDensityOptions } from '../../core/displayDensity';
import { PlatformUtil } from '../../core/utils';
import { IFilteringExpressionsTree } from '../../data-operations/filtering-expressions-tree';
import { GridBaseAPIService } from '../api.service';
import * as i0 from "@angular/core";
export declare class IgxPivotGridComponent extends IgxGridBaseDirective implements OnInit, AfterContentInit, GridType, AfterViewInit {
    selectionService: IgxGridSelectionService;
    colResizingService: IgxColumnResizingService;
    protected transactionFactory: IgxFlatTransactionFactory;
    document: any;
    protected overlayService: IgxOverlayService;
    summaryService: IgxGridSummaryService;
    protected _displayDensityOptions: IDisplayDensityOptions;
    protected platform: PlatformUtil;
    protected _diTransactions?: TransactionService<Transaction, State>;
    /**
     * Emitted when the dimension collection is changed via the grid chip area.
     *
     * @remarks
     * Returns the new dimension collection and its type:
     * @example
     * ```html
     * <igx-pivot-grid #grid [data]="localData" [height]="'305px'" [autoGenerate]="true"
     *              (dimensionsChange)="dimensionsChange($event)"></igx-grid>
     * ```
     */
    dimensionsChange: EventEmitter<IDimensionsChange>;
    /**
     * Emitted when the values collection is changed via the grid chip area.
     *
     * @remarks
     * Returns the new dimension
     * @example
     * ```html
     * <igx-pivot-grid #grid [data]="localData" [height]="'305px'" [autoGenerate]="true"
     *              (valuesChange)="valuesChange($event)"></igx-grid>
     * ```
    */
    valuesChange: EventEmitter<IValuesChange>;
    /** @hidden @internal */
    theadRow: IgxPivotHeaderRowComponent;
    pivotConfiguration: IPivotConfiguration;
    showPivotConfigurationUI: boolean;
    /**
     * @hidden @internal
     */
    role: string;
    /**
     * @hidden @internal
     */
    recordTemplate: TemplateRef<any>;
    /**
     * @hidden @internal
     */
    headerTemplate: TemplateRef<any>;
    /**
     * @hidden @interal
     */
    addRowEmptyTemplate: TemplateRef<any>;
    /**
     * @hidden @internal
     */
    snackbarDisplayTime: number;
    /**
     * @hidden @internal
     */
    cellEdit: EventEmitter<IGridEditEventArgs>;
    /**
     * @hidden @internal
     */
    cellEditDone: EventEmitter<IGridEditDoneEventArgs>;
    /**
     * @hidden @internal
     */
    cellEditEnter: EventEmitter<IGridEditEventArgs>;
    /**
     * @hidden @internal
     */
    cellEditExit: EventEmitter<IGridEditDoneEventArgs>;
    /**
     * @hidden @internal
     */
    columnMovingStart: EventEmitter<IColumnMovingStartEventArgs>;
    /**
     * @hidden @internal
     */
    columnMoving: EventEmitter<IColumnMovingEventArgs>;
    /**
     * @hidden @internal
     */
    columnMovingEnd: EventEmitter<IColumnMovingEndEventArgs>;
    /**
     * @hidden @internal
     */
    columnPin: EventEmitter<IPinColumnCancellableEventArgs>;
    /**
     * @hidden @internal
     */
    columnPinned: EventEmitter<IPinColumnEventArgs>;
    /**
     * @hidden @internal
     */
    rowAdd: EventEmitter<IGridEditEventArgs>;
    /**
     * @hidden @internal
     */
    rowAdded: EventEmitter<IRowDataEventArgs>;
    /**
     * @hidden @internal
     */
    rowDeleted: EventEmitter<IRowDataEventArgs>;
    /**
     * @hidden @internal
     */
    rowDelete: EventEmitter<IGridEditEventArgs>;
    /**
     * @hidden @internal
     */
    rowDragStart: EventEmitter<IRowDragStartEventArgs>;
    /**
     * @hidden @internal
     */
    excelStyleFilteringComponents: QueryList<IgxGridExcelStyleFilteringComponent>;
    /**
     * @hidden @internal
     */
    rowDragEnd: EventEmitter<IRowDragEndEventArgs>;
    /**
     * @hidden @internal
     */
    rowEditEnter: EventEmitter<IGridEditEventArgs>;
    /**
     * @hidden @internal
     */
    rowEdit: EventEmitter<IGridEditEventArgs>;
    /**
     * @hidden @internal
     */
    rowEditDone: EventEmitter<IGridEditDoneEventArgs>;
    /**
     * @hidden @internal
     */
    rowEditExit: EventEmitter<IGridEditDoneEventArgs>;
    /**
     * @hidden @internal
     */
    rowPinning: EventEmitter<IPinRowEventArgs>;
    /**
     * @hidden @internal
     */
    rowPinned: EventEmitter<IPinRowEventArgs>;
    columnGroupStates: Map<string, boolean>;
    dimensionDataColumns: any;
    get pivotKeys(): {
        aggregations: string;
        records: string;
        children: string;
        level: string;
        rowDimensionSeparator: string;
        columnDimensionSeparator: string;
    };
    isPivot: boolean;
    /**
     * @hidden @internal
     */
    dragRowID: any;
    protected _defaultExpandState: boolean;
    private _data;
    private _filteredData;
    private p_id;
    /**
    * Gets/Sets the default expand state for all rows.
    */
    get defaultExpandState(): boolean;
    set defaultExpandState(val: boolean);
    /**
     * @hidden @internal
     */
    get pagingMode(): GridPagingMode;
    set pagingMode(_val: GridPagingMode);
    /**
     * @hidden @internal
     */
    get hideRowSelectors(): boolean;
    set hideRowSelectors(_value: boolean);
    /**
     * @hidden @internal
     */
    get rowDraggable(): boolean;
    set rowDraggable(_val: boolean);
    /**
     * @hidden @internal
     */
    get dragIndicatorIconTemplate(): TemplateRef<any>;
    set dragIndicatorIconTemplate(_val: TemplateRef<any>);
    /**
     * @hidden @internal
     */
    get rowEditable(): boolean;
    set rowEditable(_val: boolean);
    /**
     * @hidden @internal
     */
    get pinning(): {};
    set pinning(_value: {});
    /**
     * @hidden @internal
     */
    get summaryPosition(): GridSummaryPosition;
    set summaryPosition(_value: GridSummaryPosition);
    /**
     * @hidden @interal
     */
    get summaryCalculationMode(): GridSummaryCalculationMode;
    set summaryCalculationMode(_value: GridSummaryCalculationMode);
    /**
     * @hidden @interal
     */
    get showSummaryOnCollapse(): boolean;
    set showSummaryOnCollapse(_value: boolean);
    /**
     * @hidden @internal
     */
    get hiddenColumnsCount(): any;
    /**
     * @hidden @internal
     */
    get pinnedColumnsCount(): any;
    /**
     * @hidden @internal
     */
    get batchEditing(): boolean;
    set batchEditing(_val: boolean);
    get selectedRows(): any[];
    constructor(selectionService: IgxGridSelectionService, colResizingService: IgxColumnResizingService, gridAPI: GridBaseAPIService<IgxGridBaseDirective & GridType>, transactionFactory: IgxFlatTransactionFactory, elementRef: ElementRef<HTMLElement>, zone: NgZone, document: any, cdr: ChangeDetectorRef, resolver: ComponentFactoryResolver, differs: IterableDiffers, viewRef: ViewContainerRef, appRef: ApplicationRef, moduleRef: NgModuleRef<any>, factoryResolver: ComponentFactoryResolver, injector: Injector, navigation: IgxPivotGridNavigationService, filteringService: IgxFilteringService, overlayService: IgxOverlayService, summaryService: IgxGridSummaryService, _displayDensityOptions: IDisplayDensityOptions, localeId: string, platform: PlatformUtil, _diTransactions?: TransactionService<Transaction, State>);
    /**
     * @hidden
     */
    ngOnInit(): void;
    /**
     * @hidden
     */
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    /**
     * Notifies for dimension change.
     */
    notifyDimensionChange(regenerateColumns?: boolean): void;
    uniqueDimensionValuesStrategy(column: IgxColumnComponent, exprTree: IFilteringExpressionsTree, done: (uniqueValues: any[]) => void): void;
    getDimensionData(dim: IPivotDimension, dimExprTree: IFilteringExpressionsTree, done: (colVals: any[]) => void): void;
    /** @hidden */
    featureColumnsWidth(): number;
    /**
     * Gets/Sets the value of the `id` attribute.
     *
     * @remarks
     * If not provided it will be automatically generated.
     * @example
     * ```html
     * <igx-pivot-grid [id]="'igx-pivot-1'" [data]="Data"></igx-pivot-grid>
     * ```
     */
    get id(): string;
    set id(value: string);
    /**
     * An @Input property that lets you fill the `IgxPivotGridComponent` with an array of data.
     * ```html
     * <igx-pivot-grid [data]="Data"></igx-pivot-grid>
     * ```
     */
    set data(value: any[] | null);
    /**
     * Returns an array of data set to the component.
     * ```typescript
     * let data = this.grid.data;
     * ```
     */
    get data(): any[] | null;
    /**
     * Sets an array of objects containing the filtered data.
     * ```typescript
     * this.grid.filteredData = [{
     *       ID: 1,
     *       Name: "A"
     * }];
     * ```
     */
    set filteredData(value: any);
    /**
     * Returns an array of objects containing the filtered data.
     * ```typescript
     * let filteredData = this.grid.filteredData;
     * ```
     *
     * @memberof IgxHierarchicalGridComponent
     */
    get filteredData(): any;
    /**
     * @hidden
     */
    getContext(rowData: any, rowIndex: any): any;
    get pivotRowWidths(): number;
    resolveRowDimensionWidth(dim: IPivotDimension): number;
    get rowDimensions(): IPivotDimension[];
    get columnDimensions(): IPivotDimension[];
    get filterDimensions(): IPivotDimension[];
    get values(): import("./pivot-grid.interface").IPivotValue[];
    toggleColumn(col: IgxColumnComponent): void;
    /**
     * @hidden @internal
     */
    isRecordPinnedByIndex(_rowIndex: number): any;
    /**
     * @hidden @internal
     */
    toggleColumnVisibility(_args: IColumnVisibilityChangedEventArgs): void;
    /**
     * @hidden @internal
     */
    expandAll(): void;
    /**
     * @hidden @internal
     */
    collapseAll(): void;
    /**
     * @hidden @internal
     */
    expandRow(_rowID: any): void;
    /**
     * @hidden @internal
     */
    collapseRow(_rowID: any): void;
    /**
     * @hidden @internal
     */
    get pinnedRows(): IgxGridRowComponent[];
    /**
     * @hidden @internal
     */
    get totalRecords(): number;
    set totalRecords(_total: number);
    /**
     * @hidden @internal
     */
    moveColumn(_column: IgxColumnComponent, _target: IgxColumnComponent, _pos?: DropPosition): void;
    /**
     * @hidden @internal
     */
    addRow(_data: any): void;
    /**
     * @hidden @internal
     */
    deleteRow(_rowSelector: any): any;
    /**
     * @hidden @internal
     */
    updateCell(_value: any, _rowSelector: any, _column: string): void;
    /**
     * @hidden @internal
     */
    updateRow(_value: any, _rowSelector: any): void;
    /**
     * @hidden @internal
     */
    enableSummaries(..._rest: any[]): void;
    /**
     * @hidden @internal
     */
    disableSummaries(..._rest: any[]): void;
    /**
     * @hidden @internal
     */
    pinColumn(_columnName: string | IgxColumnComponent, _index?: any): boolean;
    /**
     * @hidden @internal
     */
    unpinColumn(_columnName: string | IgxColumnComponent, _index?: any): boolean;
    /**
     * @hidden @internal
     */
    pinRow(_rowID: any, _index?: number, _row?: RowType): boolean;
    /**
     * @hidden @internal
     */
    unpinRow(_rowID: any, _row?: RowType): boolean;
    /**
     * @hidden @internal
     */
    get pinnedRowHeight(): void;
    /**
     * @hidden @internal
     */
    get hasEditableColumns(): boolean;
    /**
     * @hidden @internal
     */
    get hasSummarizedColumns(): boolean;
    /**
     * @hidden @internal
     */
    get hasMovableColumns(): boolean;
    /**
     * @hidden @internal
     */
    get pinnedDataView(): any[];
    /**
     * @hidden @internal
     */
    openAdvancedFilteringDialog(_overlaySettings?: OverlaySettings): void;
    /**
     * @hidden @internal
     */
    closeAdvancedFilteringDialog(_applyChanges: boolean): void;
    /**
     * @hidden @internal
     */
    endEdit(_commit?: boolean, _event?: Event): void;
    /**
     * @hidden @internal
     */
    beginAddRowById(_rowID: any, _asChild?: boolean): void;
    /**
     * @hidden @internal
     */
    beginAddRowByIndex(_index: number): void;
    /**
     * @hidden @internal
     */
    get totalHeight(): number;
    getColumnGroupExpandState(col: IgxColumnComponent): boolean;
    toggleRowGroup(col: IgxColumnComponent, newState: boolean): void;
    setupColumns(): void;
    protected resolveToggle(groupColumn: IgxColumnComponent, state: boolean): void;
    /**
     * @hidden
     * @internal
     */
    protected calcGridHeadRow(): void;
    /**
     * @hidden @internal
     */
    protected getDataBasedBodyHeight(): number;
    protected get hasMultipleValues(): boolean;
    /**
     * @hidden
     */
    protected autogenerateColumns(): void;
    protected generateDimensionColumns(): IgxColumnComponent[];
    protected generateFromData(fields: string[]): Map<string, any>;
    protected generateColumnHierarchy(fields: Map<string, any>, data: any, parent?: any): IgxColumnComponent[];
    protected getMeasureChildren(colFactory: any, data: any, parent: any, hidden: any, parentWidth: any): any[];
    private extractValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxPivotGridComponent, [null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, { optional: true; }, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxPivotGridComponent, "igx-pivot-grid", never, { "pivotConfiguration": "pivotConfiguration"; "showPivotConfigurationUI": "showPivotConfigurationUI"; "addRowEmptyTemplate": "addRowEmptyTemplate"; "snackbarDisplayTime": "snackbarDisplayTime"; "defaultExpandState": "defaultExpandState"; "pagingMode": "pagingMode"; "hideRowSelectors": "hideRowSelectors"; "rowDraggable": "rowDraggable"; "rowEditable": "rowEditable"; "pinning": "pinning"; "summaryPosition": "summaryPosition"; "summaryCalculationMode": "summaryCalculationMode"; "showSummaryOnCollapse": "showSummaryOnCollapse"; "batchEditing": "batchEditing"; "id": "id"; "data": "data"; "totalRecords": "totalRecords"; }, { "dimensionsChange": "dimensionsChange"; "valuesChange": "valuesChange"; "cellEdit": "cellEdit"; "cellEditDone": "cellEditDone"; "cellEditEnter": "cellEditEnter"; "cellEditExit": "cellEditExit"; "columnMovingStart": "columnMovingStart"; "columnMoving": "columnMoving"; "columnMovingEnd": "columnMovingEnd"; "columnPin": "columnPin"; "columnPinned": "columnPinned"; "rowAdd": "rowAdd"; "rowAdded": "rowAdded"; "rowDeleted": "rowDeleted"; "rowDelete": "rowDelete"; "rowDragStart": "rowDragStart"; "rowDragEnd": "rowDragEnd"; "rowEditEnter": "rowEditEnter"; "rowEdit": "rowEdit"; "rowEditDone": "rowEditDone"; "rowEditExit": "rowEditExit"; "rowPinning": "rowPinning"; "rowPinned": "rowPinned"; }, never, ["igx-grid-toolbar", "igx-grid-footer"]>;
}
