import { GridColumnDataType } from '../../data-operations/data-util';
import { FilteringExpressionsTree } from '../../data-operations/filtering-expressions-tree';
import { SortingDirection } from '../../data-operations/sorting-strategy';
import { ColumnType } from '../common/grid.interface';
export declare const DEFAULT_PIVOT_KEYS: {
    aggregations: string;
    records: string;
    children: string;
    level: string;
    rowDimensionSeparator: string;
    columnDimensionSeparator: string;
};
export interface IDimensionsChange {
    dimensions: IPivotDimension[];
    dimensionCollectionType: PivotDimensionType;
}
export interface IValuesChange {
    values: IPivotValue[];
}
export interface IPivotDimensionStrategy {
    process(collection: any, dimensions: IPivotDimension[], values: IPivotValue[], pivotKeys?: IPivotKeys): any[];
}
export declare type PivotAggregation = (members: any[], data: any[]) => any;
export interface IPivotAggregator {
    /** Aggregation unique key. */
    key: string;
    /** Aggregation label to show in the UI. */
    label: string;
    /**
     * Aggregator function can be a custom implementation of `PivotAggregation`, or
     * use predefined ones from `IgxPivotAggregate` and its variants.
     */
    aggregator: (members: any[], data?: any[]) => any;
}
/**
 * Configuration of the pivot grid.
 */
export interface IPivotConfiguration {
    /** A strategy to transform the rows. */
    rowStrategy?: IPivotDimensionStrategy | null;
    /** A strategy to transform the columns. */
    columnStrategy?: IPivotDimensionStrategy | null;
    /** A list of the rows. */
    rows: IPivotDimension[] | null;
    /** A list of the columns. */
    columns: IPivotDimension[] | null;
    /** A list of the values. */
    values: IPivotValue[] | null;
    /** Dimensions to be displayed in the filter area. */
    filters?: IPivotDimension[] | null;
    pivotKeys?: IPivotKeys;
}
export interface IPivotDimension {
    /** Allows defining a hierarchy when multiple sub groups need to be extracted from single member. */
    childLevel?: IPivotDimension;
    /** Field name to use in order to extract value. */
    memberName: string;
    /** Function that extracts the value */
    memberFunction?: (data: any) => any;
    /** Enables/Disables a particular dimension from pivot structure. */
    enabled: boolean;
    /**
     * A predefined or defined via the `igxPivotSelector` filter expression tree for the current dimension to be applied in the filter pipe.
     * */
    filter?: FilteringExpressionsTree | null;
    sortDirection?: SortingDirection;
    dataType?: GridColumnDataType;
    width?: string;
}
export interface IPivotValue {
    member: string;
    displayName?: string;
    /**
     * Active aggregator definition with key, label and aggregator.
     */
    aggregate: IPivotAggregator;
    /**
     * List of aggregates to show in aggregate drop-down.
     */
    aggregateList?: IPivotAggregator[];
    enabled: boolean;
    styles?: any;
    dataType?: GridColumnDataType;
    formatter?: (value: any, rowData?: any) => any;
}
export interface IPivotKeys {
    children: string;
    records: string;
    aggregations: string;
    level: string;
    columnDimensionSeparator: string;
    rowDimensionSeparator: string;
}
export declare enum PivotDimensionType {
    Row = 0,
    Column = 1,
    Filter = 2
}
export interface IPivotDimensionData {
    column: ColumnType;
    dimension: IPivotDimension;
    prevDimensions: IPivotDimension[];
}
